General Dashboard — Stisla

# Dashboard

#### Total Admin

10

#### News

42

#### Reports

1,201

#### Online Users

47

#### Statistics

Week Month
7%
$243
Today's Sales
23%
$2,902
This Week's Sales
9%
$12,821
This Month's Sales
19%
$92,142
This Year's Sales

#### Recent Activities

- Now
  Farhan A Mujib
  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin.
- 12m
  Ujang Maman
  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin.
- 17m
  Rizal Fakhri
  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin.
- 21m
  Alfa Zulkarnain
  Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin.

View All
Please wait

#### Authors

#### Referral URL

2,100
Google
1,880
Facebook
1,521
Bing
884
Yahoo
473
Kodinger
418
Multinity

#### Popular Browser

Chrome
48%
Firefox
26%
Safari
14%
Opera
7%
IE
5%

#### Visitors

#### This Week Stats

Filter

#### $1,053

Sold 3 items on 2 customers
View All

###### Item List (3 Items)

- $405
  PlayStation 9
  by Hasan Basri
  Sunday
- $499
  RocketZ
  by Hasan Basri
  Sunday
- $149
  Xiaomay Readme 4.0
  by Kusnaedi
  Tuesday

#### Tasks

View All

- Not Finished

  ###### Redesign header

  Alfa Zulkarnain
  Now
- Completed

  ###### Add a new component

  Serj Tankian
  4 Min
- Progress

  ###### Fix modal window

  Ujang Maman
  8 Min
- Not Finished

  ###### Remove unwanted classes

  Farhan A Mujib
  21 Min

#### Quick Draft

Title
Please fill in the title
Content

#### Latest Posts

View All

Title | Author | Action
--- | --- | ---
Introduction Laravel 5 in Web Development View | Bagus Dwi Cahya |
Laravel 5 Tutorial - Installation in Web Development View | Bagus Dwi Cahya |
Laravel 5 Tutorial - MVC in Web Development View | Bagus Dwi Cahya |
Laravel 5 Tutorial - Migration in Web Development View | Bagus Dwi Cahya |
Laravel 5 Tutorial - Deploy in Web Development View | Bagus Dwi Cahya |
Laravel 5 Tutorial - Closing in Web Development View | Bagus Dwi Cahya |